@@ -1,5 +1,6 @@
 import numpy as np
 from xrmreader.reader import read_txrm_iterable, read_metadata
+# from reader import read_txrm_iterable, read_metadata
 from scipy.ndimage import shift, convolve
 from tqdm import tqdm
 from skimage.measure import block_reduce
@@ -30,11 +31,8 @@ def revert_shifts(projections, x_shifts, y_shifts):
     shifts[:, 0] = x_shifts
     shifts[:, 1] = y_shifts
 
-    # warp each projection
+    # shift each projection
     for i in range(num_projections):
-        # T = np.float32([[1, 0, shifts[i, 0]], [0, 1, shifts[i, 1]]])
-        # projections[i, :, :] = cv2.warpAffine(projections[i, :, :], T, (img_size_x, img_size_y))
-
         # input is extended by repeating its last value to avoid zeros after cropping
         projections[i, :, :] = shift(projections[i, :, :], (shifts[i, 1], shifts[i, 0]), order=1, mode='nearest')
 
@@ -131,7 +129,6 @@ def smooth_reference(reference, kernel_size=15):
     reference = np.array(reference)
     kernel = np.ones((kernel_size, kernel_size)) / np.sum(np.ones((kernel_size, kernel_size)))
     reference_smooth = convolve(reference, kernel, mode='reflect')
-    # reference_smooth = convolve2d(reference, kernel, mode='same', boundary='symm')
     return reference_smooth
 
 
@@ -145,7 +142,7 @@ def apply_polynomial(data, coefficients):
 
 def read_and_preprocess_txrm(projections_file, downsample_factor=1, angular_factor=1, do_truncation_correction=True,
                              extension_fraction=0.1, dose_reduction=1., datatype=np.float32, keep_rows=None,
-                             do_beam_hardening_correction=False, poly=None):
+                             do_beam_hardening_correction=False, poly=None, do_shift=True):
     '''Preprocess the raw images, i.e. remove shifts, transform into line integral domain.
     Projections are extended for truncation correction if needed.
 
@@ -160,20 +157,13 @@ def read_and_preprocess_txrm(projections_file, downsample_factor=1, angular_fact
     :param datatype: numpy datatype to use for storing the projections; should be one of float16, float32, float64
     :param do_beam_hardening_correction: whether or not polynomial beam hardening correction is applied
     :param poly: coefficients for beam hardening correction
+    :param do_shift: if shift correction should be performed while loading the projections or in the projection images
     :return:
     '''
     metadata = read_metadata(str(projections_file))
     num_images = metadata['number_of_images']
-    x_shifts_detector = metadata['x-shifts'][::angular_factor]
-    y_shifts_detector = metadata['y-shifts'][::angular_factor]
-    x_shifts_temperature = metadata['temperature-x-shifts'][::angular_factor]
-    y_shifts_temperature = metadata['temperature-y-shifts'][::angular_factor]
-    x_shifts_amc = metadata['AMC-x-shifts'][::angular_factor]
-    y_shifts_amc = metadata['AMC-y-shifts'][::angular_factor]
-    x_shifts_source = metadata['source-x-shifts'][::angular_factor]
-    y_shifts_source = metadata['source-y-shifts'][::angular_factor]
-    x_shifts = x_shifts_detector + x_shifts_amc - x_shifts_amc[0] / 2 * np.ones_like(x_shifts_amc)
-    y_shifts = y_shifts_detector + y_shifts_amc - y_shifts_amc[0] / 2 * np.ones_like(y_shifts_amc)
+    x_shifts = metadata['x-shifts'][::angular_factor]
+    y_shifts = metadata['y-shifts'][::angular_factor]
     reference = metadata['reference']
     if not dose_reduction == 1.:
         reference_smooth = smooth_reference(reference)
@@ -185,14 +175,12 @@ def read_and_preprocess_txrm(projections_file, downsample_factor=1, angular_fact
     if do_truncation_correction:
         projections = np.zeros((int(np.ceil(num_images / angular_factor)),
                                 projection_height,
-                                #int(np.ceil(float(metadata['image_height']) / downsample_factor)),
                                 int(np.ceil(float(metadata['image_width']) / downsample_factor)) + 2 * int(
                                     np.ceil(float(metadata['image_width']) / downsample_factor) * extension_fraction)),
                                dtype=datatype)
     else:
         projections = np.zeros((int(np.ceil(num_images / angular_factor)),
                                 projection_height,
-                                #int(np.ceil(float(metadata['image_height']) / downsample_factor)),
                                 int(np.ceil(float(metadata['image_width']) / downsample_factor))),
                                dtype=datatype)
 
@@ -203,7 +191,8 @@ def read_and_preprocess_txrm(projections_file, downsample_factor=1, angular_fact
                 x_shifts, y_shifts)), total=np.ceil(num_images / angular_factor)):
         projection = np.expand_dims(projection, 0)
         projection = divide_by_reference(projection, reference)
-        projection = revert_shifts(projection, x_shift, y_shift)
+        if do_shift:
+            projection = revert_shifts(projection, x_shift, y_shift)
         if keep_rows is not None:
             projection = projection[:, keep_rows, :]
         projection = negative_logarithm(projection)
