@@ -476,7 +476,9 @@ def read_ole_metadata(ole):
             'power': _read_ole_value(ole, 'AcquisitionSettings/SrcPower', '<f'),
             'exposure_time': _read_ole_value(ole, 'AcquisitionSettings/ExpTime', '<f'),
             'binning': _read_ole_value(ole, 'AcquisitionSettings/Binning', '<I'),
-            'filter': _read_ole_value(ole, 'AcquisitionSettings/SourceFilterName', '<260s')
+            'filter': _read_ole_value(ole, 'AcquisitionSettings/SourceFilterName', '<260s'),
+            'scaling_min': _read_ole_value(ole, 'GlobalMinMax/GlobalMin', '<f'),
+            'scaling_max': _read_ole_value(ole, 'GlobalMinMax/GlobalMax', '<f')
         }
     else:
         metadata = {
@@ -519,7 +521,9 @@ def read_ole_metadata(ole):
             'power': _read_ole_value(ole, 'AcquisitionSettings/SrcPower', '<f'),
             'exposure_time': _read_ole_value(ole, 'AcquisitionSettings/ExpTime', '<f'),
             'binning': _read_ole_value(ole, 'AcquisitionSettings/Binning', '<I'),
-            'filter': _read_ole_value(ole, 'AcquisitionSettings/SourceFilterName', '<260s')
+            'filter': _read_ole_value(ole, 'AcquisitionSettings/SourceFilterName', '<260s'),
+            'scaling_min': _read_ole_value(ole, 'GlobalMinMax/GlobalMin', '<f'),
+            'scaling_max': _read_ole_value(ole, 'GlobalMinMax/GlobalMax', '<f')
         }
 
     try:
